@@ -29,9 +29,12 @@ class Stats(object):
     message.num_files_per_type = self.get_num_files_per_type()
 
     message.locales = [str(locale) for locale in self.pod.list_locales()]
-    message.langs = self.pod.get_translations().list_locales()
-    catalog = self.pod.get_translations().get_catalog()
-    message.num_messages = len(catalog) if catalog else 0
+    message.langs = self.pod.catalogs.list_locales()
+    if self.pod.catalogs.exists:
+      catalog = self.pod.catalogs.get_template()
+      message.num_messages = len(catalog)
+    else:
+      message.num_messages = 0
     return message
 
   def to_string(self):
