@@ -26,30 +26,39 @@ You can get a static file from the pod.
   file = pod.get_file('/podspec.yaml')
 """
 
+from . import env as environment
+from . import files
+from . import locales
+from . import messages
+from . import podspec
+from . import routes
+from . import storage
+from . import catalog_holder
+from .collectionz import collectionz
+from .controllers import tags
+from .preprocessors import preprocessors
+from .tests import tests
+from grow.common import utils
+from grow.deployments import deployments
 import copy
 import jinja2
 import logging
 import os
 import re
-from grow.common import utils
-from grow.deployments import deployments
-from grow.pods import files
-from grow.pods import locales
-from grow.pods import messages
-from grow.pods import podspec
-from grow.pods import routes
-from grow.pods import storage
-from grow.pods import tests
-from grow.pods import translations
-from grow.pods.collectionz import collectionz
-from grow.pods.controllers import tags
-from grow.pods.preprocessors import preprocessors
 
 
 class Error(Exception):
   pass
 
 
+class PodDoesNotExistError(Error, IOError):
+  pass
+
+
+class PodSpecParseError(Error):
+  pass
+
+
 class BuildError(Error):
   pass
 
@@ -59,14 +68,14 @@ class BuildError(Error):
 
 class Pod(object):
 
-  def __init__(self, root, changeset=None, storage=storage.auto):
+  def __init__(self, root, changeset=None, storage=storage.auto, env=None):
     self.storage = storage
     self.root = root if self.storage.is_cloud_storage else os.path.abspath(root)
     self.changeset = changeset
+    self.env = env if env else environment.Env(environment.EnvConfig(host='localhost'))
 
-    self.routes = routes.Routes(pod=self)
     self.locales = locales.Locales(pod=self)
-    self.translations = translations.Translations(pod=self)
+    self.catalogs = catalog_holder.Catalogs(pod=self)
     self.tests = tests.Tests(pod=self)
 
   def __repr__(self):
@@ -78,17 +87,32 @@ class Pod(object):
     return self.file_exists('/podspec.yaml')
 
   @property
-  @utils.memoize
   def yaml(self):
-    try:
-      return utils.parse_yaml(self.read_file('/podspec.yaml'))[0]
-    except IOError:
-      raise Error('Pod does not exist or malformed podspec.yaml.')
+    return self._parse_yaml()
 
   @property
+  def routes(self):
+    # Rebuilding routes with each access of the routes propery prevents
+    # caching issues with data files. TODO: Rebuild routes only when routes
+    # and data files change.
+    return routes.Routes(pod=self)
+
+  def reset_yaml(self):
+    self._parse_yaml.reset()
+
   @utils.memoize
+  def _parse_yaml(self):
+    try:
+      return utils.parse_yaml(self.read_file('/podspec.yaml'))
+    except IOError as e:
+      path = self.abs_path('/podspec.yaml')
+      if e.args[0] == 2 and e.filename:
+        raise PodDoesNotExistError('Pod does not exist: {}'.format(path))
+      raise PodSpecParseError('Error parsing: {}'.format(path))
+
+  @property
   def podspec(self):
-    return podspec.Podspec(pod=self)
+    return podspec.Podspec(yaml=self.yaml)
 
   @property
   def error_routes(self):
@@ -102,12 +126,12 @@ class Pod(object):
   def title(self):
     return self.yaml.get('title')
 
+  def match(self, path):
+    return self.routes.match(path, env=self.env.to_wsgi_env())
+
   def get_routes(self):
     return self.routes
 
-  def get_translations(self):
-    return self.translations
-
   def abs_path(self, pod_path):
     path = os.path.join(self.root, pod_path.lstrip('/'))
     return os.path.join(self.root, path)
@@ -168,9 +192,6 @@ class Pod(object):
     pod_path = os.path.join('/content', collection_path)
     return collectionz.Collection.get(pod_path, _pod=self)
 
-  def get_translation_catalog(self, locale):
-    return self.translations.get_translation(locale)
-
   def duplicate_to(self, other, exclude=None):
     """Duplicates this pod to another pod."""
     if not isinstance(other, self.__class__):
@@ -190,7 +211,7 @@ class Pod(object):
     output = {}
     routes = self.get_routes()
     for path in routes.list_concrete_paths():
-      controller = routes.match(path)
+      controller = self.match(path)
       output[path] = controller.render()
 
     error_controller = routes.match_error('/404.html')
@@ -244,10 +265,12 @@ class Pod(object):
     kind = deployment_params.pop('destination')
     try:
       config = destination_configs[nickname]
-      deployment = deployments.make_deployment(kind, config)
+      deployment = deployments.make_deployment(kind, config, name=nickname)
     except TypeError:
       logging.exception('Invalid deployment parameters.')
       raise
+    if deployment.config.keep_control_dir:
+      deployment.pod = self
     return deployment
 
   def list_locales(self):
@@ -259,15 +282,12 @@ class Pod(object):
     preprocessor_config = copy.deepcopy(self.yaml.get('preprocessors', []))
     for params in preprocessor_config:
       kind = params.pop('kind')
-      preprocessor = preprocessors.Preprocessor.get(kind, pod=self)
-      preprocessor.set_params(**params)
+      preprocessor = preprocessors.make_preprocessor(kind, params, self)
       results.append(preprocessor)
     return results
 
   def preprocess(self):
-    # Preprocess translations.
-    translations_obj = self.get_translations()
-    translations_obj.recompile_mo_files()
+    self.catalogs.compile()  # Preprocess translations.
     for preprocessor in self.list_preprocessors():
       preprocessor.run()
 
@@ -278,7 +298,7 @@ class Pod(object):
     _template_loader = self.storage.JinjaLoader(self.root)
     env = jinja2.Environment(
         loader=_template_loader, autoescape=True, trim_blocks=True,
-        extensions=['jinja2.ext.i18n'])
+        extensions=['jinja2.ext.i18n', 'jinja2.ext.do'])
     env.filters['markdown'] = tags.markdown_filter
     env.filters['render'] = tags.render_filter
     return env
@@ -290,3 +310,6 @@ class Pod(object):
     if not path_format:
       return '/'
     return path_format.format(**{'locale': locale})
+
+  def test(self):
+    self.tests.run()
