@@ -8,16 +8,13 @@ SUFFIX_PATTERN = re.compile('[.](' + '|'.join(map(re.escape, SUFFIXES)) + ')$')
 
 
 class TranslationPreprocessor(base.BasePreprocessor):
-
   KIND = '_translation'
 
   def __init__(self, pod):
     self.pod = pod
 
   def first_run(self):
-    # Recompile MO files.
-    translations_obj = self.pod.get_translations()
-    translations_obj.recompile_mo_files()
+    self.pod.catalogs.compile()
 
   def run(self):
     # TODO(jeremydw): Ideally, this would be capable of flushing the gettext cache and
