@@ -1,7 +1,5 @@
 from grow.common import utils
 from grow.pods import storage
-from grow.server import podgroups
-import gflags as flags
 import jinja2
 import logging
 import os
@@ -9,28 +7,16 @@ import webapp2
 import webob
 import werkzeug
 
-FLAGS = flags.FLAGS
-
-flags.DEFINE_boolean(
-    'debug', False, 'Whether to show debug output.')
-
 _root = os.path.join(utils.get_grow_dir(), 'server', 'templates')
 _loader = storage.FileStorage.JinjaLoader(_root)
 _env = jinja2.Environment(loader=_loader, autoescape=True, trim_blocks=True,
                           extensions=['jinja2.ext.i18n'])
 
 
-def set_pod_root(root):
-  if root is None and 'grow:pod_root' in os.environ:
-    del os.environ['grow:pod_root']
-  if root is not None:
-    os.environ['grow:pod_root'] = root
-
-
 class BaseHandler(webapp2.RequestHandler):
 
   def handle_exception(self, exception, debug):
-    if FLAGS.debug:
+    if debug:
       logging.exception(exception)
     else:
       logging.error(str(exception))
@@ -53,16 +39,9 @@ class BaseHandler(webapp2.RequestHandler):
 class PodHandler(BaseHandler):
 
   def get(self):
-    if 'grow:pod_root' not in os.environ:
-      raise Exception('Environment variable "grow:pod_root" missing.')
-    domain = self.request.host
-    url_scheme = self.request.scheme
-    root = os.path.dirname(os.environ['grow:pod_root'])
-    podgroup = podgroups.Podgroup(root)
-    pod_name = os.path.basename(os.path.normpath(os.environ['grow:pod_root']))
-    podgroup.load_pods_by_id([pod_name])
+    pod = self.app.registry['pod']
     try:
-      controller = podgroup.match(self.request.path, domain=domain, url_scheme=url_scheme)
+      controller = pod.routes.match(self.request.path, self.request.environ)
       self.respond_with_controller(controller)
     except werkzeug.routing.RequestRedirect as e:
       self.redirect(e.new_url)
